@@ -8,6 +8,12 @@ import os
 import gitignore_parser
 
 
+import ast
+import os
+import argparse
+import chardet
+import gitignore_parser
+
 def describe_directory(directory, ignore_git=True):
     """
     Recursively describe all files in a directory.
@@ -30,6 +36,8 @@ def describe_directory(directory, ignore_git=True):
                     module_data = {}
                     functions = {}
                     classes = {}
+                    parser = argparse.ArgumentParser(description='Describe Python directory')
+
                     for node in module.body:
                         if isinstance(node, ast.FunctionDef):
                             signature = ast.unparse(node.args)
@@ -55,6 +63,7 @@ def describe_directory(directory, ignore_git=True):
                                     methods.update({method.name.replace(" ", "") + "(" + signature.replace(" ",
                                                "") + ")": docstring})
                             classes.update({node.name.replace(" ", ""): {"methods": methods}})
+
                     if functions:
                         module_data["functions"] = functions
                     if classes:
@@ -62,13 +71,17 @@ def describe_directory(directory, ignore_git=True):
                     if module_data:
                         output[path.replace(" ", "")] = module_data
 
-    # add argparse help text to output
-    parser = argparse.ArgumentParser(description='Describe Python directory')
-    help_text = parser.format_help()
-    output['argparse_help'] = _clean_output(help_text)
+                    # add argparse help text to module data
+                    parser.print_help()
+                    help_text = parser.format_help()
+                    module_data["argparse_help"] = _clean_output(help_text)
 
     return output
 
+
+
+
+
 def _clean_output(output):
     """
     Removes extra spaces, tabs, and newlines from argparse output.
